from jonsung import is_hangle, has_jongsung
import unittest

class HangleTestCase(unittest.TestCase):

    def setUp(self):
        self.kor = [ 
         '한글',
         '안녕',
         '하윙',
         '테스트케이스',
         'enflish영어'
        ]
        self.not_kor = [
            'english',
            '영어eng',
            '132r4eng',
            'dinvf,5'
        ]

    def test_line_count(self):
        for v in self.kor:
            self.assertTrue(is_hangle(v))
        
        for v in self.not_kor:
            self.assertFalse(is_hangle(v))

if __name__ == '__main__':
    unittest.main()


#-*- coding: utf-8 -*-
import re
from exceptions import NotHangleException

START_HANGLE = 44032
J_IDX = 28

def is_hangle(string: str) -> bool:
    last_char = string[-1]
    if re.match('.*[ㄱ-ㅎㅏ-ㅣ가-힣]+.*', last_char) is None:
        return False
    return True

def has_jongsung(string: str)  -> bool:
    if not is_hangle(string):
        raise NotHangleException

    last_char = string[-1]
    if (ord(last_char) - START_HANGLE) % J_IDX > 0:
        return True
    return  False


# TODO: can we make above functions as Decorator?


from jonsung import has_jongsung

class Josa:
    def __init__(self):
        pass

    @staticmethod
    def get_josa(string, josa):
        if (josa == '을') or (josa =='를'):
            return '을' if has_jongsung(string) else '를'
        elif (josa == '은') or (josa =='는'):
            return '는' if has_jongsung(string) else '은'
        elif (josa == '이') or (josa =='가'):
            return '이' if has_jongsung(string) else '가'
        else:
            raise Exception("아직 구현중임")



    @staticmethod
    def get_full_string(string, josa):
        pass

# TODO: make main function as class's static method? or not a class's static method just a function.


if __name__ =="__main__":
    s = '오리'
    s2 = '철수'
    
    print(f'{s}{Josa.get_josa(s, "이")}') # 오리가 
    print(f'{s2}{Josa.get_josa(s2, "을")}') # 철수를
    # 사용법이 너무 어려워 보이는데?
    # 더 나은 사용법 제공을 위해 고민하기.


from setuptools  import setup,  find_packages

setup(
    name = 'pyjosa',
    version = '0.0.4',
    description = 'now it is test',
    author = 'sehwan.kim',
    author_email = 'sehwan.kim@ingkle.com',
    url = 'https://github.com/kimsehwan96/pyjosa',
    packages = find_packages(exclude=[]),
    license='MIT',
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3.7'
    ],
    package_data = {},
    zip_safe=False,
    keyword = ['pypi test'],

)